==> open-xchange-subscribe_6.22.1.orig.tar.bz2: open-xchange-subscribe-6.22.1/com.openexchange.subscribe.yahoo/src/com/openexchange/subscribe/yahoo/osgi/Activator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.yahoo.osgi;

import org.apache.commons.logging.Log;
import com.openexchange.log.LogFactory;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.context.ContextService;
import com.openexchange.oauth.OAuthService;
import com.openexchange.oauth.OAuthServiceMetaData;
import com.openexchange.oauth.yahoo.YahooService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.subscribe.SubscribeService;
import com.openexchange.subscribe.yahoo.YahooSubscribeService;

/**
 * {@link Activator}
 *
 * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
 */
public class Activator extends HousekeepingActivator {

    private OAuthServiceMetaData oAuthServiceMetaData;

    private YahooService yahooService;

    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Activator.class));

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { OAuthService.class, ContextService.class, YahooService.class};
    }

    @Override
    protected void startBundle() throws Exception {
     // react dynamically to the appearance/disappearance of OAuthMetaDataService for MSN
        final ServiceTracker<OAuthServiceMetaData,OAuthServiceMetaData> metaDataTracker = new ServiceTracker<OAuthServiceMetaData,OAuthServiceMetaData>(context, OAuthServiceMetaData.class, new OAuthServiceMetaDataRegisterer(context, this));
        rememberTracker(metaDataTracker);
        openTrackers();
        yahooService = getService(YahooService.class);
        registerSubscribeService();
    }


    public void registerSubscribeService() {
        final YahooSubscribeService yahooSubscribeService = new YahooSubscribeService(this);
        registerService(SubscribeService.class, yahooSubscribeService);
        LOG.info("YahooSubscribeService was started");
    }

    public void unregisterSubscribeService() {
        unregisterServices();
        LOG.info("YahooSubscribeService was stopped");
    }

    public OAuthServiceMetaData getOAuthServiceMetaData() {
        return oAuthServiceMetaData;
    }


    public void setOAuthServiceMetaData(final OAuthServiceMetaData authServiceMetaData) {
        oAuthServiceMetaData = authServiceMetaData;
    }


    public YahooService getYahooService() {
        return yahooService;
    }


    public void setYahooService(final YahooService yahooService) {
        this.yahooService = yahooService;
    }



}

==> open-xchange-subscribe_7.4.0.orig.tar.bz2: open-xchange-subscribe-7.4.0/com.openexchange.subscribe.yahoo/src/com/openexchange/subscribe/yahoo/osgi/Activator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.yahoo.osgi;

import org.osgi.framework.ServiceRegistration;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.context.ContextService;
import com.openexchange.oauth.OAuthService;
import com.openexchange.oauth.OAuthServiceMetaData;
import com.openexchange.oauth.yahoo.YahooService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.subscribe.SubscribeService;
import com.openexchange.subscribe.yahoo.YahooSubscribeService;

/**
 * {@link Activator}
 *
 * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
 */
public class Activator extends HousekeepingActivator {

    private volatile OAuthServiceMetaData oAuthServiceMetaData;
    private volatile YahooService yahooService;
    private ServiceRegistration<SubscribeService> serviceRegistration;

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { OAuthService.class, ContextService.class, YahooService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        // react dynamically to the appearance/disappearance of OAuthMetaDataService for MSN
        final ServiceTracker<OAuthServiceMetaData, OAuthServiceMetaData> metaDataTracker =
            new ServiceTracker<OAuthServiceMetaData, OAuthServiceMetaData>(
                context,
                OAuthServiceMetaData.class,
                new OAuthServiceMetaDataRegisterer(context, this));
        rememberTracker(metaDataTracker);
        openTrackers();
        yahooService = getService(YahooService.class);
        //registerSubscribeService();
    }

    /**
     * Registers the subscribe service.
     */
    public synchronized void registerSubscribeService() {
        if (null == serviceRegistration) {
            serviceRegistration = context.registerService(SubscribeService.class, new YahooSubscribeService(this), null);
            com.openexchange.log.Log.loggerFor(Activator.class).info("YahooSubscribeService was started");
        }
    }

    /**
     * Un-registers the subscribe service.
     */
    public synchronized void unregisterSubscribeService() {
        final ServiceRegistration<SubscribeService> serviceRegistration = this.serviceRegistration;
        if (null != serviceRegistration) {
            serviceRegistration.unregister();
            this.serviceRegistration = null;
            com.openexchange.log.Log.loggerFor(Activator.class).info("YahooSubscribeService was stopped");
        }
    }

    public OAuthServiceMetaData getOAuthServiceMetaData() {
        return oAuthServiceMetaData;
    }

    public void setOAuthServiceMetaData(final OAuthServiceMetaData authServiceMetaData) {
        oAuthServiceMetaData = authServiceMetaData;
    }

    public YahooService getYahooService() {
        return yahooService;
    }

    public void setYahooService(final YahooService yahooService) {
        this.yahooService = yahooService;
    }

}
